/*
	Copyright (C) 2025  hexlocation (hex@iwakura.rip) & grngxd (grng@iwakura.rip)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
package types

import (
	"errors"
	"fmt"

	"github.com/gin-gonic/gin"
)

type StereoError struct {
	Code       int
	StatusCode int
}

func (e *StereoError) Throw(c *gin.Context, err error) {
	c.JSON(e.StatusCode, gin.H{
		"code":    e.Code,
		"success": false,
	})

	if err != nil {
		c.Error(err)
	} else {
		c.Error(errors.New(fmt.Sprintf("Got an error with code: %v", e.Code)))
	}
}

var ErrorFileNotFound = StereoError{
	Code:       0,
	StatusCode: 404,
}

var ErrorReaderOpen = StereoError{
	Code:       1,
	StatusCode: 500,
}

var ErrorUnauthorized = StereoError{
	Code:       2,
	StatusCode: 401,
}

var ErrorInvalidParams = StereoError{
	Code:       3,
	StatusCode: 400,
}

var ErrorEmptyFile = StereoError{
	Code:       4,
	StatusCode: 400,
}

var ErrorInvalidFile = StereoError{
	Code:       5,
	StatusCode: 400,
}

var ErrorDatabase = StereoError{
	Code:       6,
	StatusCode: 500,
}

var ErrorS3 = StereoError{
	Code:       7,
	StatusCode: 500,
}

var ErrorUserNotFound = StereoError{
	Code:       8,
	StatusCode: 404,
}
